@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1693 2025/01/24 09:26:53 ajacoutot Exp $
+# $OpenBSD: Quirks.pm,v 1.1697 2025/02/09 08:57:12 rsadowski Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -60,6 +60,8 @@ my $base_exceptions = {
 # 6.9
 	'acme-client' => '/usr/sbin/acme-client',
 	'libexecinfo' => '/usr/include/execinfo.h',
+# 7.7
+	'p5-Test2-Suite' => '/usr/libdata/perl5/Test2/Suite.pm',
 };
 
 my $stem_extensions = {
@@ -614,6 +616,8 @@ my $stem_extensions = {
 	'gstreamer1-plugins-good' => 'gst-plugins-good',
 	'gstreamer1-plugins-libav' => 'gst-libav',
 	'gstreamer1-plugins-ugly' => 'gst-plugins-ugly',
+	'libksane-kf5' => 'libksane',
+	'marble-kf5' => 'marble',
 };
 
 my $obsolete_reason = {};
@@ -1230,6 +1234,9 @@ setup_obsolete_reason(
 	0 => 'burpsuite',
 	7 => 'govc',
 	7 => 'vcsim',
+	5 => 'sqlite',
+	3 => 'swish-e',
+	3 => 'p5-SWISH-API',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
